-- CreateExtension
CREATE EXTENSION IF NOT EXISTS "postgis";

-- Required to use postgis extension :
-- set the search_path to both public and territory (where is postgis) AND the current schema
SET search_path TO matcher, territory, public;

-- CreateTable
CREATE TABLE "ad" (
    "uuid" UUID NOT NULL,
    "driver" BOOLEAN NOT NULL,
    "passenger" BOOLEAN NOT NULL,
    "frequency" INTEGER NOT NULL,
    "fromDate" DATE NOT NULL,
    "toDate" DATE NOT NULL,
    "monTime" TIMESTAMPTZ NOT NULL,
    "tueTime" TIMESTAMPTZ NOT NULL,
    "wedTime" TIMESTAMPTZ NOT NULL,
    "thuTime" TIMESTAMPTZ NOT NULL,
    "friTime" TIMESTAMPTZ NOT NULL,
    "satTime" TIMESTAMPTZ NOT NULL,
    "sunTime" TIMESTAMPTZ NOT NULL,
    "monMargin" INTEGER NOT NULL,
    "tueMargin" INTEGER NOT NULL,
    "wedMargin" INTEGER NOT NULL,
    "thuMargin" INTEGER NOT NULL,
    "friMargin" INTEGER NOT NULL,
    "satMargin" INTEGER NOT NULL,
    "sunMargin" INTEGER NOT NULL,
    "driverDuration" INTEGER NOT NULL,
    "driverDistance" INTEGER NOT NULL,
    "passengerDuration" INTEGER NOT NULL,
    "passengerDistance" INTEGER NOT NULL,
    "originType" SMALLINT NOT NULL,
    "destinationType" SMALLINT NOT NULL,
    "waypoints" geography(LINESTRING),
    "direction" geography(LINESTRING),
    "fwdAzimuth" INTEGER NOT NULL,
    "backAzimuth" INTEGER NOT NULL,
    "seatsDriver" SMALLINT NOT NULL,
    "seatsPassenger" SMALLINT NOT NULL,
    "seatsUsed" SMALLINT NOT NULL,
    "createdAt" TIMESTAMP(3) NOT NULL DEFAULT CURRENT_TIMESTAMP,
    "updatedAt" TIMESTAMP(3) NOT NULL DEFAULT CURRENT_TIMESTAMP,

    CONSTRAINT "ad_pkey" PRIMARY KEY ("uuid")
);

-- CreateIndex
CREATE INDEX "ad_driver_idx" ON "ad"("driver");

-- CreateIndex
CREATE INDEX "ad_passenger_idx" ON "ad"("passenger");

-- CreateIndex
CREATE INDEX "ad_fromDate_idx" ON "ad"("fromDate");

-- CreateIndex
CREATE INDEX "ad_toDate_idx" ON "ad"("toDate");

-- CreateIndex
CREATE INDEX "ad_fwdAzimuth_idx" ON "ad"("fwdAzimuth");

-- CreateIndex
CREATE INDEX "direction_idx" ON "ad" USING GIST ("direction");
