import { MatchRequest } from '../../../../domain/dtos/match.request';
import { Candidate } from '../../../../domain/entities/engine/candidate';
import { AlgorithmType } from '../../../../domain/types/algorithm.enum';
import { IDefaultParams } from '../../../../domain/types/default-params.type';
import { MatchQuery } from '../../../../queries/match.query';
import { Filter } from '../../../../domain/entities/engine/processor/filter/filter.abstract';

const mockGeorouterCreator = {
  create: jest.fn().mockImplementation(),
};

const mockTimezoneFinder = {
  timezones: jest.fn().mockImplementation(),
};

const defaultParams: IDefaultParams = {
  DEFAULT_UUID: '00000000-0000-0000-0000-000000000000',
  MARGIN_DURATION: 900,
  VALIDITY_DURATION: 365,
  DEFAULT_TIMEZONE: 'Europe/Paris',
  DEFAULT_SEATS: 3,
  DEFAULT_ALGORITHM_SETTINGS: {
    algorithm: AlgorithmType.CLASSIC,
    strict: false,
    remoteness: 15000,
    useProportion: true,
    proportion: 0.3,
    useAzimuth: true,
    azimuthMargin: 10,
    maxDetourDistanceRatio: 0.3,
    maxDetourDurationRatio: 0.3,
    georouterType: 'graphhopper',
    georouterUrl: 'http://localhost',
  },
};

const matchRequest: MatchRequest = new MatchRequest();
matchRequest.departure = '2023-04-01 12:00';
matchRequest.waypoints = [
  {
    lat: 49.440041,
    lon: 1.093912,
  },
  {
    lat: 50.630992,
    lon: 3.045432,
  },
];
const matchQuery: MatchQuery = new MatchQuery(
  matchRequest,
  defaultParams,
  mockGeorouterCreator,
  mockTimezoneFinder,
);

class FakeFilter extends Filter {
  filter = (candidates: Candidate[]): Candidate[] => {
    return candidates;
  };
}

describe('Filter', () => {
  it('should create an extended class', () => {
    expect(new FakeFilter(matchQuery)).toBeDefined();
  });

  it('should call complete method', () => {
    const fakeFilter: Filter = new FakeFilter(matchQuery);
    const filterSpy = jest.spyOn(fakeFilter, 'filter');
    fakeFilter.execute([new Candidate()]);
    expect(filterSpy).toHaveBeenCalled();
  });
});
